@@ -44,7 +44,7 @@ def fetch_tracks(sp, item_type, url):
                     track_num = track_info.get("track_number")
                     spotify_id = track_info.get("id")
                     track_name = track_info.get("name")
-                    track_artist = ",".join(
+                    track_artist = ", ".join(
                         [artist["name"] for artist in track_info.get("artists")]
                     )
                     if track_album_info:
@@ -219,7 +219,7 @@ def parse_spotify_url(url):
     if url.startswith("spotify:"):
         log.error("Spotify URI was provided instead of a playlist/album/track URL.")
         sys.exit(1)
-    parsed_url = url.replace("https://open.spotify.com/", "")
+    parsed_url = url.replace("https://open.spotify.com/", "").split("?")[0]
     item_type = parsed_url.split("/")[0]
     item_id = parsed_url.split("/")[1]
     return item_type, item_id
