@@ -2,6 +2,8 @@ import urllib.request
 from os import path
 import os
 import multiprocessing
+
+import json
 import mutagen
 import csv
 import yt_dlp
@@ -25,6 +27,30 @@ def playlist_num_filename(**kwargs):
     return f"{kwargs['track_num']} - {default_filename(**kwargs)}"
 
 
+def dump_json(songs):
+    """
+    Outputs the JSON response of ydl.extract_info to stdout
+    :param songs: the songs for which the JSON should be output
+    """
+    for song in songs:
+        query = f"{song.get('artist')} - {song.get('name')} Lyrics".replace(
+            ":", ""
+        ).replace('"', "")
+
+        ydl_opts = {"quiet": True}
+
+        with yt_dlp.YoutubeDL(ydl_opts) as ydl:
+            try:
+                ytJson = ydl.extract_info("ytsearch:" + query, False)
+                print(json.dumps(ytJson.get("entries")))
+            except Exception as e:  # skipcq: PYL-W0703
+                log.debug(e)
+                print(
+                    f"Failed to download {song.get('name')}, make sure yt_dlp is up to date"
+                )
+                continue
+
+
 def write_tracks(tracks_file, song_dict):
     """
     Writes the information of all tracks in the playlist[s] to a text file in csv kind of format
@@ -120,6 +146,7 @@ def find_and_download_songs(kwargs):
     """
     sponsorblock_postprocessor = []
     reference_file = kwargs["reference_file"]
+    files = {}
     with open(reference_file, "r", encoding="utf-8") as file:
         for line in file:
             temp = line.split(";")
@@ -138,7 +165,6 @@ def find_and_download_songs(kwargs):
             )
 
             if kwargs["use_sponsorblock"][0].lower() == "y":
-
                 sponsorblock_postprocessor = [
                     {
                         "key": "SponsorBlock",
@@ -150,19 +176,30 @@ def find_and_download_songs(kwargs):
                         "force_keyframes": True,
                     },
                 ]
+            save_path = kwargs["track_db"][i]["save_path"]
+            file_path = path.join(save_path, file_name)
 
-            file_path = path.join(kwargs["track_db"][i]["save_path"], file_name)
+            mp3file_path = f"{file_path}.mp3"
 
-            mp3filename = f"{file_path}.mp3"
-            mp3file_path = path.join(mp3filename)
+            if save_path not in files:
+                path_files = set()
+                files[save_path] = path_files
+            else:
+                path_files = files[save_path]
 
-            if kwargs["no_overwrites"] and not kwargs["skip_mp3"] and path.exists(mp3file_path):
-                print(f'File {mp3filename} already exists, we do not overwrite it ')
+            path_files.add(f"{file_name}.mp3")
+
+            if (
+                kwargs["no_overwrites"]
+                and not kwargs["skip_mp3"]
+                and path.exists(mp3file_path)
+            ):
+                print(f"File {mp3file_path} already exists, we do not overwrite it ")
                 continue
 
             outtmpl = f"{file_path}.%(ext)s"
             ydl_opts = {
-                "proxy": kwargs.get('proxy'),
+                "proxy": kwargs.get("proxy"),
                 "default_search": "ytsearch",
                 "format": "bestaudio/best",
                 "outtmpl": outtmpl,
@@ -192,7 +229,13 @@ def find_and_download_songs(kwargs):
                     log.debug(e)
                     print(f"Failed to download {name}, make sure yt_dlp is up to date")
             if not kwargs["skip_mp3"]:
-                set_tags(temp, mp3filename, kwargs)
+                set_tags(temp, mp3file_path, kwargs)
+        if kwargs["remove_trailing_tracks"] == "y":
+            for save_path in files:
+                for f in os.listdir(save_path):
+                    if f not in files[save_path]:
+                        print(f"File {f} is not in the playlist anymore, we delete it")
+                        os.remove(path.join(save_path, f))
 
 
 def multicore_find_and_download_songs(kwargs):
